@@ -27,14 +27,8 @@
   OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 **********************************************************************/
 
-#include <immintrin.h>
-#include <stdint.h>
-#include <string.h>
-#include <assert.h>
-#include "igzip_lib.h"
 #include "huff_codes.h"
 #include "huffman.h"
-#include "bitbuf2.h"
 #include "flatten_ll.h"
 
 /* The order code length codes are written in the dynamic code header. This is
@@ -42,21 +36,21 @@
 static const uint8_t code_length_code_order[] =
     { 16, 17, 18, 0, 8, 7, 9, 6, 10, 5, 11, 4, 12, 3, 13, 2, 14, 1, 15 };
 
-const uint32_t len_code_extra_bits[] = {
+static const uint32_t len_code_extra_bits[] = {
 	0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0,
 	0x1, 0x1, 0x1, 0x1, 0x2, 0x2, 0x2, 0x2,
 	0x3, 0x3, 0x3, 0x3, 0x4, 0x4, 0x4, 0x4,
 	0x5, 0x5, 0x5, 0x5, 0x0
 };
 
-const uint32_t dist_code_extra_bits[] = {
+static const uint32_t dist_code_extra_bits[] = {
 	0x0, 0x0, 0x0, 0x0, 0x1, 0x1, 0x2, 0x2,
 	0x3, 0x3, 0x4, 0x4, 0x5, 0x5, 0x6, 0x6,
 	0x7, 0x7, 0x8, 0x8, 0x9, 0x9, 0xa, 0xa,
 	0xb, 0xb, 0xc, 0xc, 0xd, 0xd
 };
 
-struct hufftables_icf static_hufftables = {
+static struct hufftables_icf static_hufftables = {
 	.lit_len_table = {
 			  {{{.code_and_extra = 0x00c,.length2 = 0x8}}},
 			  {{{.code_and_extra = 0x08c,.length2 = 0x8}}},
@@ -624,6 +618,9 @@ struct slver isal_create_hufftables_subset_slver = { 0x0087, 0x01, 0x00 };
 extern uint32_t build_huff_tree(struct heap_tree *heap, uint64_t heap_size, uint64_t node_ptr);
 extern void build_heap(uint64_t * heap, uint64_t heap_size);
 
+static uint32_t convert_dist_to_dist_sym(uint32_t dist);
+static uint32_t convert_length_to_len_sym(uint32_t length);
+
 static const uint8_t bitrev8[0x100] = {
 	0x00, 0x80, 0x40, 0xC0, 0x20, 0xA0, 0x60, 0xE0,
 	0x10, 0x90, 0x50, 0xD0, 0x30, 0xB0, 0x70, 0xF0,
@@ -683,7 +680,7 @@ void isal_update_histogram_base(uint8_t * start_stream, int length,
 	end_stream = start_stream + length;
 	memset(last_seen, 0, sizeof(histogram->hash_table));	/* Initialize last_seen to be 0. */
 	for (current = start_stream; current < end_stream - 3; current++) {
-		literal = *(uint32_t *) current;
+		literal = load_u32(current);
 		hash = compute_hash(literal) & LVL0_HASH_MASK;
 		seen = last_seen[hash];
 		last_seen[hash] = (current - start_stream) & 0xFFFF;
@@ -703,7 +700,7 @@ void isal_update_histogram_base(uint8_t * start_stream, int length,
 					end = end_stream - 3;
 				next_hash++;
 				for (; next_hash < end; next_hash++) {
-					literal = *(uint32_t *) next_hash;
+					literal = load_u32(next_hash);
 					hash = compute_hash(literal) & LVL0_HASH_MASK;
 					last_seen[hash] = (next_hash - start_stream) & 0xFFFF;
 				}
@@ -717,66 +714,32 @@ void isal_update_histogram_base(uint8_t * start_stream, int length,
 		}
 		lit_len_histogram[literal & 0xFF] += 1;
 	}
-	literal = literal >> 8;
-	hash = compute_hash(literal) & LVL0_HASH_MASK;
-	seen = last_seen[hash];
-	last_seen[hash] = (current - start_stream) & 0xFFFF;
-	dist = (current - start_stream - seen) & 0xFFFF;
-	if (dist < D) {
-		match_length = compare258(current - dist, current, end_stream - current);
-		if (match_length >= SHORTEST_MATCH) {
-			dist_histogram[convert_dist_to_dist_sym(dist)] += 1;
-			lit_len_histogram[convert_length_to_len_sym(match_length)] += 1;
-			lit_len_histogram[256] += 1;
-			return;
-		}
-	} else
-		lit_len_histogram[literal & 0xFF] += 1;
-	lit_len_histogram[(literal >> 8) & 0xFF] += 1;
-	lit_len_histogram[(literal >> 16) & 0xFF] += 1;
+
+	for (; current < end_stream; current++)
+		lit_len_histogram[*current] += 1;
+
 	lit_len_histogram[256] += 1;
 	return;
 }
 
-uint32_t convert_dist_to_dist_sym(uint32_t dist)
+/**
+ * @brief  Returns the deflate symbol value for a look back distance.
+ */
+static uint32_t convert_dist_to_dist_sym(uint32_t dist)
 {
 	assert(dist <= 32768 && dist > 0);
-	if (dist <= 2)
-		return dist - 1;
-	else if (dist <= 4)
-		return 0 + (dist - 1) / 1;
-	else if (dist <= 8)
-		return 2 + (dist - 1) / 2;
-	else if (dist <= 16)
-		return 4 + (dist - 1) / 4;
-	else if (dist <= 32)
-		return 6 + (dist - 1) / 8;
-	else if (dist <= 64)
-		return 8 + (dist - 1) / 16;
-	else if (dist <= 128)
-		return 10 + (dist - 1) / 32;
-	else if (dist <= 256)
-		return 12 + (dist - 1) / 64;
-	else if (dist <= 512)
-		return 14 + (dist - 1) / 128;
-	else if (dist <= 1024)
-		return 16 + (dist - 1) / 256;
-	else if (dist <= 2048)
-		return 18 + (dist - 1) / 512;
-	else if (dist <= 4096)
-		return 20 + (dist - 1) / 1024;
-	else if (dist <= 8192)
-		return 22 + (dist - 1) / 2048;
-	else if (dist <= 16384)
-		return 24 + (dist - 1) / 4096;
-	else if (dist <= 32768)
-		return 26 + (dist - 1) / 8192;
-	else
-		return ~0;	/* ~0 is an invalid distance code */
-
+	if (dist <= 32768) {
+		uint32_t msb = dist > 4 ? bsr(dist - 1) - 2 : 0;
+		return (msb * 2) + ((dist - 1) >> msb);
+	} else {
+		return ~0;
+	}
 }
 
-uint32_t convert_length_to_len_sym(uint32_t length)
+/**
+ * @brief  Returns the deflate symbol value for a repeat length.
+ */
+static uint32_t convert_length_to_len_sym(uint32_t length)
 {
 	assert(length > 2 && length < 259);
 
@@ -967,6 +930,7 @@ static inline uint32_t fix_code_lens(struct heap_tree *heap_space, uint32_t root
 				code_len--;
 		}
 
+		bl_count[0] = 0;
 		for (i = 1; i <= code_len; i++)
 			bl_count[i] = code_len_count[i];
 		for (; i <= max_code_len; i++)
@@ -979,6 +943,7 @@ static inline uint32_t fix_code_lens(struct heap_tree *heap_space, uint32_t root
 			for (; code_len_count[k] == 0; k++) ;
 		}
 	} else {
+		bl_count[0] = 0;
 		for (i = 1; i <= code_len; i++)
 			bl_count[i] = code_len_count[i];
 		for (; i <= max_code_len; i++)
@@ -1007,8 +972,16 @@ gen_huff_code_lens(struct heap_tree *heap_space, uint32_t heap_size, uint32_t *
 
 }
 
-inline uint32_t set_huff_codes(struct huff_code *huff_code_table, int table_length,
-			       uint32_t * count)
+/**
+ * @brief Determines the code each element of a deflate compliant huffman tree and stores
+ * it in a lookup table
+ * @requires table has been initialized to already contain the code length for each element.
+ * @param table: A lookup table used to store the codes.
+ * @param table_length: The length of table.
+ * @param count: a histogram representing the number of occurences of codes of a given length
+ */
+static inline uint32_t set_huff_codes(struct huff_code *huff_code_table, int table_length,
+				      uint32_t * count)
 {
 	/* Uses the algorithm mentioned in the deflate standard, Rfc 1951. */
 	int i;
@@ -1063,11 +1036,24 @@ static inline uint32_t set_dist_huff_codes(struct huff_code *codes, uint32_t * b
 	return max_code;
 }
 
-int create_huffman_header(struct BitBuf2 *header_bitbuf,
-			  struct huff_code *lookup_table,
-			  struct rl_code *huffman_rep,
-			  uint16_t huffman_rep_length, uint32_t end_of_block,
-			  uint32_t hclen, uint32_t hlit, uint32_t hdist)
+/**
+ * @brief Creates the header for run length encoded huffman trees.
+ * @param header: the output header.
+ * @param lookup_table: a huffman lookup table.
+ * @param huffman_rep: a run length encoded huffman tree.
+ * @extra_bits: extra bits associated with the corresponding spot in huffman_rep
+ * @param huffman_rep_length: the length of huffman_rep.
+ * @param end_of_block: Value determining whether end of block header is produced or not;
+ * 0 corresponds to not end of block and all other inputs correspond to end of block.
+ * @param hclen: Length of huffman code for huffman codes minus 4.
+ * @param hlit: Length of literal/length table minus 257.
+ * @parm hdist: Length of distance table minus 1.
+ */
+static int create_huffman_header(struct BitBuf2 *header_bitbuf,
+				 struct huff_code *lookup_table,
+				 struct rl_code *huffman_rep,
+				 uint16_t huffman_rep_length, uint32_t end_of_block,
+				 uint32_t hclen, uint32_t hlit, uint32_t hdist)
 {
 	/* hlit, hdist, hclen are as defined in the deflate standard, head is the
 	 * first three deflate header bits.*/
@@ -1104,9 +1090,19 @@ int create_huffman_header(struct BitBuf2 *header_bitbuf,
 	return bit_count;
 }
 
-inline int create_header(struct BitBuf2 *header_bitbuf, struct rl_code *huffman_rep,
-			 uint32_t length, uint64_t * histogram, uint32_t hlit,
-			 uint32_t hdist, uint32_t end_of_block)
+/**
+ * @brief Creates the dynamic huffman deflate header.
+ * @returns Returns the  length of header in bits.
+ * @requires This function requires header is large enough to store the whole header.
+ * @param header: The output header.
+ * @param lit_huff_table: A literal/length code huffman lookup table.\
+ * @param dist_huff_table: A distance huffman code lookup table.
+ * @param end_of_block: Value determining whether end of block header is produced or not;
+ * 0 corresponds to not end of block and all other inputs correspond to end of block.
+ */
+static inline int create_header(struct BitBuf2 *header_bitbuf, struct rl_code *huffman_rep,
+				uint32_t length, uint64_t * histogram, uint32_t hlit,
+				uint32_t hdist, uint32_t end_of_block)
 {
 	int i;
 
@@ -1249,8 +1245,15 @@ static inline uint32_t rl_encode(uint16_t * codes, uint32_t num_codes, uint64_t
 	return (uint32_t) (pout - out);
 }
 
-void create_code_tables(uint16_t * code_table, uint8_t * code_length_table, uint32_t length,
-			struct huff_code *hufftable)
+/**
+ * @brief Creates a two table representation of huffman codes.
+ * @param code_table: output table containing the code
+ * @param code_size_table: output table containing the code length
+ * @param length: the lenght of hufftable
+ * @param hufftable: a huffman lookup table
+ */
+static void create_code_tables(uint16_t * code_table, uint8_t * code_length_table,
+			       uint32_t length, struct huff_code *hufftable)
 {
 	int i;
 	for (i = 0; i < length; i++) {
@@ -1259,7 +1262,16 @@ void create_code_tables(uint16_t * code_table, uint8_t * code_length_table, uint
 	}
 }
 
-void create_packed_len_table(uint32_t * packed_table, struct huff_code *lit_len_hufftable)
+/**
+ * @brief Creates a packed representation of length huffman codes.
+ * @details In packed_table, bits 32:8 contain the extra bits appended to the huffman
+ * code and bits 8:0 contain the code length.
+ * @param packed_table: the output table
+ * @param length: the length of lit_len_hufftable
+ * @param lit_len_hufftable: a literal/length huffman lookup table
+ */
+static void create_packed_len_table(uint32_t * packed_table,
+				    struct huff_code *lit_len_hufftable)
 {
 	int i, count = 0;
 	uint16_t extra_bits;
@@ -1289,8 +1301,16 @@ void create_packed_len_table(uint32_t * packed_table, struct huff_code *lit_len_
 	    (lit_len_hufftable[LIT_LEN - 1].length);
 }
 
-void create_packed_dist_table(uint32_t * packed_table, uint32_t length,
-			      struct huff_code *dist_hufftable)
+/**
+ * @brief Creates a packed representation of distance  huffman codes.
+ * @details In packed_table, bits 32:8 contain the extra bits appended to the huffman
+ * code and bits 8:0 contain the code length.
+ * @param packed_table: the output table
+ * @param length: the length of lit_len_hufftable
+ * @param dist_hufftable: a distance huffman lookup table
+ */
+static void create_packed_dist_table(uint32_t * packed_table, uint32_t length,
+				     struct huff_code *dist_hufftable)
 {
 	int i, count = 0;
 	uint16_t extra_bits;
@@ -1319,8 +1339,15 @@ void create_packed_dist_table(uint32_t * packed_table, uint32_t length,
 	}
 }
 
-int are_hufftables_useable(struct huff_code *lit_len_hufftable,
-			   struct huff_code *dist_hufftable)
+/**
+ * @brief Checks to see if the hufftable is usable by igzip
+ *
+ * @param lit_len_hufftable: literal/length huffman code
+ * @param dist_hufftable: distance huffman code
+ * @returns Returns 0 if the table is usable
+ */
+static int are_hufftables_useable(struct huff_code *lit_len_hufftable,
+				  struct huff_code *dist_hufftable)
 {
 	int max_lit_code_len = 0, max_len_code_len = 0, max_dist_code_len = 0;
 	int dist_extra_bits = 0, len_extra_bits = 0;
@@ -1385,7 +1412,6 @@ int isal_create_hufftables(struct isal_hufftables *hufftables,
 	uint16_t *dcodes = hufftables->dcodes;
 	uint8_t *lit_table_sizes = hufftables->lit_table_sizes;
 	uint8_t *dcodes_sizes = hufftables->dcodes_sizes;
-	uint8_t *deflate_hdr = hufftables->deflate_hdr;
 	uint64_t *lit_len_histogram = histogram->lit_len_histogram;
 	uint64_t *dist_histogram = histogram->dist_histogram;
 
@@ -1425,7 +1451,7 @@ int isal_create_hufftables(struct isal_hufftables *hufftables,
 	create_packed_len_table(len_table, lit_huff_table);
 	create_packed_dist_table(dist_table, IGZIP_DIST_TABLE_SIZE, dist_huff_table);
 
-	set_buf(&header_bitbuf, deflate_hdr, sizeof(deflate_hdr));
+	set_buf(&header_bitbuf, hufftables->deflate_hdr, sizeof(hufftables->deflate_hdr));
 	init(&header_bitbuf);
 
 	hlit = max_lit_len_sym - 256;
@@ -1476,7 +1502,6 @@ int isal_create_hufftables_subset(struct isal_hufftables *hufftables,
 	uint16_t *dcodes = hufftables->dcodes;
 	uint8_t *lit_table_sizes = hufftables->lit_table_sizes;
 	uint8_t *dcodes_sizes = hufftables->dcodes_sizes;
-	uint8_t *deflate_hdr = hufftables->deflate_hdr;
 	uint64_t *lit_len_histogram = histogram->lit_len_histogram;
 	uint64_t *dist_histogram = histogram->dist_histogram;
 
@@ -1518,7 +1543,7 @@ int isal_create_hufftables_subset(struct isal_hufftables *hufftables,
 	create_packed_len_table(len_table, lit_huff_table);
 	create_packed_dist_table(dist_table, IGZIP_DIST_TABLE_SIZE, dist_huff_table);
 
-	set_buf(&header_bitbuf, deflate_hdr, sizeof(deflate_hdr));
+	set_buf(&header_bitbuf, hufftables->deflate_hdr, sizeof(hufftables->deflate_hdr));
 	init(&header_bitbuf);
 
 	hlit = max_lit_len_sym - 256;
@@ -1545,7 +1570,7 @@ int isal_create_hufftables_subset(struct isal_hufftables *hufftables,
 	return 0;
 }
 
-void expand_hufftables_icf(struct hufftables_icf *hufftables)
+static void expand_hufftables_icf(struct hufftables_icf *hufftables)
 {
 	uint32_t i, eb, j, k, len, code;
 	struct huff_code orig[21], *p_code;
