@@ -7,7 +7,7 @@ public class CompressionUnitTestBase {
     protected int compatibilityTestsBufferSize;
     protected byte[] compatibilityInputBuffer;
     protected static final String compatibilityTestsDataProviderName = "gzipOnlyCompressionCases";
-    private final boolean simplifyDNAForCompatibilityTests = false;  // if set dna array will be fully filled with 'A'
+    static private final boolean simplifyDNAForCompatibilityTests = false;  // if set dna array will be fully filled with 'A'
                                                                     // otherwise random array of set {A,C,G,T} will be generated
 
     @BeforeClass()
